//file homogamy.dta

//section standardizing cross-tabulations

//slide ------------------------------------------------------------------------
//title The influence of marginal distributions

/*txt
{pstd}
Consider the example below

{pstd}
It shows the race of the husband and the race of the wife for couples living in 
the USA that got married between 2010 and 2017

{pstd}
The races are very unequaly distributed in the USA

{pstd}
We can control for one marginal distribution by computing row or collumn 
percentages.
txt*/

//ex
use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, row nofreq
//endex

/*txt
{pstd}
We see racial homogamy: people tend to marry someone of the same race

{pstd}
However, several things are hard to see in this table:

{pmore}
{cmd:Are whites really the most closed group} or is there a substantial 
"colorblind" group of whites that accidentally married another white because that
is the largest group? 

{pmore}
{cmd:Are Native Americans really so much less homogamous} or are we seeing an 
artifact caused by the small number of native american women (0.6%)?

{pmore}
If native Americans were mixing around randomly, then we would expect much less 
native american males marrying native american females. Apperently native 
American men still prefer native American women but because there are so many 
other women around he will still have a good chance of eventually marrying another
women. 

{pmore}
{cmd:Is there symetery in this table}, e.g. are hispanic males as likely to marry a 
white female as hispanic females are to marry white males?

{pmore}
It does not seem to be the case from this table, but 5% from all white males 
could be similar to 18% from all hispanic males. 

{pstd}
There is something mechanical about the influence of the margins, and it is 
common (in sociology) to want to look at the pattern in the table nett of this 
influence of the marginal distributions.

{pstd}
We could do this by looking at odds ratios , but here I want to show an alternative.
txt*/

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Odds ratios

/*txt
{pstd}
The odds is the number of "successes" per "failure"

{pstd}
The odds ratio is a ratio of odds, and this measure of association is indpendent
of the marginal distributions
txt*/

//ex
tab racem racef [fw=freq] if marcoh == 2010
di 122904 / 136200
di 134486 / 31956989
di (122904 / 136200)/(134486 / 31956989)
//endex

/*txt
{pstd}
The odds that a native ameriance man marries a native american women and not a 
white women is 0.9.

{pmore}
The odds that a white man marries a native american women and not a white women
is 0.004.

{pstd}
The odds of marrying a native american women compared to a white women is 214 
times larger for native American man than for white man. 

txt*/
//endslide  --------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Standardizing tables

/*txt
{pstd}
When we do a chi squared test for cross-tabulations we compare observed cell counts 
with predicted cell counts 

{pstd}
For these predicted cell counts we assume that the margins remain as observed, 
but otherwise there is no association between the variables (the odds ratios are
all 1).

{pstd}
In the table of predicted cell counts the only pattern is due to the margins.
txt*/

//ex
tab racem racef [fw=freq] if marcoh==2010, exp
//endex

/*txt
{pstd}
Can't we reverse that? Keep the association (odds ratios) as observed but fix 
the margins. 

{pstd}
For example we could fix all margins at a 100.

{pstd}
That way we can look at the proportion native American men marrying native American
women when they weren't such a small group.

{pstd}
This is what standardizing tables does (Yule 1912). This is implemented in the 
{helpb stdtable} package.
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010
//endex

/*txt
{pstd}
{cmd:stdtable} is thus very useful in conjunction with a chi-squared test for 
cross-tabulations:

{pmore}
The chi-squared test tells you whether or not there is a pattern in the table 
that is significantly different from independence

{pmore}
{cmd:stdtable} tells you what that pattern is.
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Displaying results from stdtable

/*txt
{pstd}
We can add options to make the table look better
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010, ///
         format(%5.0f)  
//endex


/*txt 
We can compare across groups
txt*/

//ex
stdtable racem racef [fw=freq], by(marcoh) format(%5.0f)
//endex

/*txt
{pstd}
Alternatively we can replace the data in memory with standardized counts and 
use those to create a graph
txt*/

//ex
qui stdtable racem racef [fw=freq],          ///
    by(marcoh) replace
	
tabplot racem marcoh [iw=std],               ///
    by(racef, compact note("") cols(6)       ///
	   t1title("race, wife"))                ///
    xlab( 1(1)7, angle(35) labsize(vsmall) )
//endex

//endslide ---------------------------------------------------------------------

//section Estimation
//slide ------------------------------------------------------------------------
//title Iterative Proportional fitting

/*txt
{pstd}
The idea to change the margins to be all 100, but otherwise leave everything as
much as possible the same.

{pstd}
We know how to do that for just row totals: 

{pmore}
divide all cells by its rowtotal and multiply by 100
txt*/

//ex
use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, matcell(data)

mata
data = st_matrix("data")

muhat = data

muhat = muhat:/rowsum(muhat):*100
end
//endex

/*txt
{pstd}
We could do the same with the column totals
txt*/

//ex
mata
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end
//endex

/*txt
{pstd}
This is close, but not quite.

{pstd}
What happens when we repeat that a couple of times
txt*/

//ex
mata
muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end
//endex

/*txt
{pstd}
Again, better and we can imagine that with some extra iterations we would get 
where we want to be.

{pstd}
This is iterative proportional fitting (Kruithof 1937; Deming and Stephan 1940)
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Can all tables be standardized?

/*txt
{pstd}Consider the following table{p_end}

        0 0 2
        1 5 2
        8 7 0
	
{pstd}In order to make the first row total 100, the top right cell {it:must} be 
100{p_end}	

{pstd}In order to make the last column total 100, the top right cell {it:cannot} 
be 100{p_end}

{pstd}This is an example of a table that cannot be standardized, and the algorithm 
will not converge.
txt*/
//endslide ---------------------------------------------------------------------
