//layout toc title(subsubsection) link(subsubsection) secbold 
//layout toc subsubsubsecitalic 
//layout bib bibfile(standardize.bib) authorstyle("last first")
//file homogamy.dta
//dir stdtable/source
//dir stdtable/presentation
//dir stdtable/handout
//file stdtable/source/standardize.bib
//file stdtable/source/homogamy.dta

//toctitle Making interactive presentations in Stata

/*toctxt

{center:Maarten L. Buis}
{center:University of Konstanz}

toctxt*/

//section Example presentation: stdtable, a package to standardize tables
//subsection standardizing cross-tabulations

//slide ------------------------------------------------------------------------
//title The influence of marginal distributions

/*txt
{pstd}
Consider the example below

{pstd}
It shows the race of the husband and the race of the wife for couples living in 
the USA that got married between 2010 and 2017

{pstd}
The races are very unequaly distributed in the USA

{pstd}
We can control for one marginal distribution by computing row or collumn 
percentages.
txt*/

//ex
use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, row nofreq
//endex

/*txt
{pstd}
We see racial homogamy: people tend to marry someone of the same race

{pstd}
However, several things are hard to see in this table:

{pmore}
{cmd:Are whites really the most closed group} or is there a substantial 
"colorblind" group of whites that accidentally married another white because that
is the largest group? 

{pmore}
{cmd:Are Native Americans really so much less homogamous} or are we seeing an 
artifact caused by the small number of native american women (0.6%)?

{pmore}
If native Americans were mixing around randomly, then we would expect much less 
native american males marrying native american females. Apperently native 
American men still prefer native American women but because there are so many 
other women around he will still have a good chance of eventually marrying another
women. 

{pmore}
{cmd:Is there symetery in this table}, e.g. are hispanic males as likely to marry a 
white female as hispanic females are to marry white males?

{pmore}
It does not seem to be the case from this table, but 5% from all white males 
could be similar to 18% from all hispanic males. 

{pstd}
There is something mechanical about the influence of the margins, and it is 
common (in sociology) to want to look at the pattern in the table nett of this 
influence of the marginal distributions.

{pstd}
We could do this by looking at /*digr*/ , but here I want to show an alternative.
txt*/

//endslide ---------------------------------------------------------------------

//digr -------------------------------------------------------------------------
//title Odds ratios
//label odds ratios

/*txt
{pstd}
The odds is the number of "successes" per "failure"

{pstd}
The odds ratio is a ratio of odds, and this measure of association is indpendent
of the marginal distributions
txt*/

//ex
tab racem racef [fw=freq] if marcoh == 2010
di 122904 / 136200
di 134486 / 31956989
di (122904 / 136200)/(134486 / 31956989)
//endex

/*txt
{pstd}
The odds that a native ameriance man marries a native american women and not a 
white women is 0.9.

{pmore}
The odds that a white man marries a native american women and not a white women
is 0.004.

{pstd}
The odds of marrying a native american women compared to a white women is 214 
times larger for native American man than for white man. 

txt*/
//enddigr  ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Standardizing tables

/*txt
{pstd}
When we do a chi squared test for cross-tabulations we compare observed cell counts 
with predicted cell counts 

{pstd}
For these predicted cell counts we assume that the margins remain as observed, 
but otherwise there is no association between the variables (the odds ratios are
all 1).

{pstd}
In the table of predicted cell counts the only pattern is due to the margins.
txt*/

//ex
tab racem racef [fw=freq] if marcoh==2010, exp
//endex

/*txt
{pstd}
Can't we reverse that? Keep the association (odds ratios) as observed but fix 
the margins. 

{pstd}
For example we could fix all margins at a 100.

{pstd}
That way we can look at the proportion native American men marrying native American
women when they weren't such a small group.

{pstd}
This is what standardizing tables does /*cite yule12 */. This is implemented in the 
{helpb stdtable} package.
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010
//endex

/*txt
{pstd}
{cmd:stdtable} is thus very useful in conjunction with a chi-squared test for 
cross-tabulations:

{pmore}
The chi-squared test tells you whether or not there is a pattern in the table 
on top of what is imposed by the margins. 

{pmore}
{cmd:stdtable} tells you what that pattern is.
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Displaying results from stdtable

/*txt
{pstd}
We can add options to make the table look better
txt*/

//ex
stdtable racem racef [fw=freq] if marcoh == 2010, ///
         format(%5.0f)  
//endex


/*txt 
{pstd}
We can compare across groups
txt*/

//ex
stdtable racem racef [fw=freq], by(marcoh) format(%5.0f)
//endex

/*txt
{pstd}
Alternatively we can replace the data in memory with standardized counts and 
use those to create a graph
txt*/

//ex
qui stdtable racem racef [fw=freq],          ///
    by(marcoh) replace
	
tabplot racem marcoh [iw=std],               ///
    by(racef, compact note("") cols(6)       ///
	   t1title("race, wife"))                ///
    xlab( 1(1)7, angle(35) labsize(vsmall) )
//endex
//graph Graph

//endslide ---------------------------------------------------------------------

//subsection Estimation
//slide ------------------------------------------------------------------------
//title Iterative Proportional fitting

/*txt
{pstd}
The idea to change the margins to be all 100, but otherwise leave everything as
much as possible the same.

{pstd}
We know how to do that for just row totals: 

{pmore}
divide all cells by its rowtotal and multiply by 100
txt*/

//ex
use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, matcell(data)

mata
data = st_matrix("data")

muhat = data

muhat = muhat:/rowsum(muhat):*100
end
//endex

/*txt
{pstd}
We could do the same with the column totals
txt*/

//ex
mata
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end
//endex

/*txt
{pstd}
This is close, but not quite.

{pstd}
What happens when we repeat that a couple of times
txt*/

//ex
mata
muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end
//endex

/*txt
{pstd}
Again, better and we can imagine that with some extra iterations we would get 
where we want to be.

{pstd}
This is iterative proportional fitting /*cite kruithof37 deming_stephan40 */
txt*/
//endslide ---------------------------------------------------------------------

//anc --------------------------------------------------------------------------
//title Can all tables be standardized?

/*txt
{pstd}Consider the following table{p_end}

        0 0 2
        1 5 2
        8 7 0
	
{pstd}In order to make the first row total 100, the top right cell {it:must} be 
100{p_end}	

{pstd}In order to make the last column total 100, the top right cell {it:cannot} 
be 100{p_end}

{pstd}This is an example of a table that cannot be standardized, and the algorithm 
will not converge.
txt*/
//endanc -----------------------------------------------------------------------

//section How to create a smcl presentation
//subsection creating the presentation
//slide ------------------------------------------------------------------------
//title Getting started

/*txt
{pstd}
I start with creating a folder for my presentation, with three sub-folders:

{pmore}source{p_end}
{pmore}presentation{p_end}
{pmore}handout{p_end}

{pstd}
I then start brainstorming about what I want to do in my presentation.

{pstd}
I typically do this in a text file in the {it:source} directory, that will later 
become a .do file, so I put the text in comments

{pstd}
Here is the .do file for the example presentation

//codefile stdtable/source/stdtable01.do stdtable01.do

{pstd}
Next step is to create the examples

//codefile stdtable/source/stdtable02.do stdtable02.do

{pstd}
Next step is to Indicate when a slide begins with {cmd://slide} and ends with 
{cmd://endslide}

{pstd}
With the {cmd://title} one specifies the title of the slide

{pstd}
Examples are indicated by {cmd://ex} and {cmd://endex}

{pstd}
Indicate any datasets or other files that the presentation needs with 
{cmd://file} {it:filename}

{pstd}
Sections are indicated by {cmd://section} {it:section_name}

{pstd}
This is what we get:

//codefile stdtable/source/stdtable03.do stdtable03.do

{pstd}
This is already a sourcefile we can use for {cmd:smclpres}
txt*/

//ex
smclpres using stdtable\source\stdtable03.do , replace dir(stdtable/presentation)
cd stdtable/presentation
dir
cd ../..
//endex
//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Adding text

/*txt
{pstd}
You can add a text block by starting a line with {cmd:/*txt} and ending it with 
{cmd:txt*/}

{pstd}
The text will be formatted using SMCL, which is documented in {help smcl:help smcl}

{pstd}
The most important directives are:

{pmore}
{cmd:{c -(}pstd{c )-}} starts a standard paragraph

{pmore}
{cmd:{c -(}pmore{c )-}} starts an indented paragraph

{pmore}
{cmd:{c -(}p_end{c )-}} ends a paragraph

{pmore}
{cmd:{c -(}help} {it:cmd_name}{cmd:{c )-}} adds a link to the helpfile of {it:cmd_name}.

{pstd}
The sourcefile after including text looks like this:

//codefile stdtable/source/stdtable04.do stdtable04.do
txt*/

//ex
smclpres using stdtable\source\stdtable04.do , replace dir(stdtable/presentation)
//endex

//endslide ---------------------------------------------------------------------


//slide ------------------------------------------------------------------------
//title Different kinds of slides

/*txt
{pstd}
The {bf:normal slides} (what we have used thus far) represent the main linear flow of
the presentation.

{pstd}
We can also add {bf:digression slides}. The arrows at the bottom of a slide will skip 
it, but you must add a link to it in a text block on the previous regular slide.

{pstd}
So during the presentation, the presenter can easily decide whether or not to 
skip the digression slide.

{pmore}
You specify the digression slide using {cmd://digr} and {cmd://enddigr}

{pmore}
You specify the where the link will appear in the previous slide using {cmd:/*digr*/}

{pmore}
You specify the label used for the link using {cmd://label}

{pstd}
Alternatively we can add a ancillary slide, which can only be accessed from the
index slide

{pstd}
This type of slide serves the purpose of an appendix.

{pmore}
You specify the {bf:ancillary slide} using {cmd://anc} and {cmd://endanc}

{pstd}
The sourcefile after including a digression and an ancillary slide looks like this:

//codefile stdtable/source/stdtable05.do stdtable05.do
txt*/

//ex
smclpres using stdtable\source\stdtable05.do , replace dir(stdtable/presentation)
//endex
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Changing the look of the table of contents

/*txt
{pstd}
You can specify settings for the overall layout of the presentation using the 
{cmd://layout} command. 

{pstd} 
For example, {cmd://layout toc title(subsection)} specifies that the slide titles
are added to the table of content as a subsection.

{pmore}
In our example presentation we add the slide titles to the table of contents, 
make those slide titles links rather than the sections, and make the sections bold

{pstd}
The title of the table of contents can be specified with the {cmd://toctitle} 
command, and you can add text between the title and the table of contentents with 
the {cmd:/*toctxt} and {cmd:toctxt*/} commands

{pstd}
The sourcefile after changing the table contents looks like this:

//codefile stdtable/source/stdtable06.do stdtable06.do
txt*/

//ex
smclpres using stdtable\source\stdtable06.do , replace dir(stdtable/presentation)
//endex

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding references

/*txt
{pstd}
You can add references from a BibTex library to a {cmd:smclpres} presentation.

{pstd}
You tell {cmd:smclpres} which library to use with 
{cmd://layout bib bibfile(}{it:bibtex_file}{cmd:)}

{pstd}
After that you add references using {cmd:/*cite} {it:bibtex_key} {cmd:*/}

{pstd}
At the end of the presentation you add the references-slide using {cmd://bib} and
{cmd://endbib}, and within that slide indicate where the references are to appear 
with {cmd://bib_here}.

The sourcefile after adding references looks like this:

//codefile stdtable/source/stdtable07.do stdtable07.do
txt*/

//ex
smclpres using stdtable\source\stdtable07.do , replace dir(stdtable/presentation)
//endex

//endslide ---------------------------------------------------------------------

//subsection creating a handout
//slide ------------------------------------------------------------------------
//title Initial handout

/*txt
{pstd}
.smcl presentations are good at illustrating how to use Stata

{pstd}
However, they are inconvenient for the audience if they later want to look 
something up from that presentation

{pstd}
The {cmd:pres2html} command will turn a .smcl presentation into a .html handout

{pstd}{stata "cd stdtable/presentation"}{p_end}
{pstd}{stata "pres2html using stdtable07.smcl, dir(../handout) replace"}{p_end}
{pstd}{stata "cd ../.."}{p_end}
txt*/

//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding graphs to the handout

/*txt
{pstd}
Notice that the graph is not displayed in the handout

{pstd}
You can tell {cmd:pres2html} that a graph needs to be added with the command 
{cmd://graph} {it:graphname}. 

{pstd}
The sourcefile after adding that looks like this:

//codefile stdtable/source/stdtable08.do stdtable08.do
 
{pstd}{stata "smclpres using stdtable/source/stdtable08.do , replace dir(stdtable/presentation)"}{p_end}
{pstd}{stata "pres2html using stdtable/presentation/stdtable08.smcl, replace dir(stdtable/handout)"}{p_end}
txt*/
//endslide ---------------------------------------------------------------------

//slide ------------------------------------------------------------------------
//title Adding contents or output of a .do file to the handout

/*txt
{pstd}
In this presentation I added a lot of links to .do files. In the handout we would
want a copy of those .do files in the handout. 

{pstd}
This can be done using the {cmd://codefile} {it:filename label} command.

{pstd}
In a teaching context I use this when including some small excercises with the
solution in the .do file.
txt*/
//endslide ---------------------------------------------------------------------


//bib --------------------------------------------------------------------------
//title References

//bib_here

//endbib -----------------------------------------------------------------------
